@@ -26,11 +26,11 @@
  * DKBTrace was originally written by David K. Buck.
  * DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
  * ---------------------------------------------------------------------------
- * $File: //depot/public/povray/3.x/vfe/vfesession.h $
- * $Revision: #1 $
- * $Change: 6069 $
- * $DateTime: 2013/11/06 11:59:40 $
- * $Author: chrisc $
+ * $File: //depot/povray/smp/vfe/vfesession.h $
+ * $Revision: #33 $
+ * $Change: 6132 $
+ * $DateTime: 2013/11/25 14:23:41 $
+ * $Author: clipka $
  *******************************************************************************/
 
 #ifndef __VFESESSION_H__
@@ -516,7 +516,7 @@ namespace vfe
       // Returns a copy of the shared pointer containing the current instance
       // of a pov_frontend::Display-derived render preview instance, which may
       // be NULL.
-      virtual boost::shared_ptr<Display> GetDisplay() const;
+      virtual shared_ptr<Display> GetDisplay() const;
 
       // If a VFE implementation has provided a display creator functor via
       // vfeSession::SetDisplayCreator(), this method will call it with the
